@@ -88,6 +88,7 @@ require('../../node_modules/core-js/modules/es6.object.keys.js');
 require('../../node_modules/core-js/modules/es6.object.prevent-extensions.js');
 require('../../node_modules/core-js/modules/es6.object.seal.js');
 require('../../node_modules/core-js/modules/es6.object.set-prototype-of.js');
+require('../../node_modules/core-js/modules/es6.object.to-string.js');
 require('../../node_modules/core-js/modules/es6.promise.js');
 require('../../node_modules/core-js/modules/es6.reflect.apply.js');
 require('../../node_modules/core-js/modules/es6.reflect.construct.js');
@@ -144,6 +145,7 @@ require('../../node_modules/core-js/modules/es6.typed.uint8-array.js');
 require('../../node_modules/core-js/modules/es6.typed.uint8-clamped-array.js');
 require('../../node_modules/core-js/modules/es6.weak-map.js');
 require('../../node_modules/core-js/modules/es6.weak-set.js');
+require('../../node_modules/core-js/modules/es7.array.flat-map.js');
 require('../../node_modules/core-js/modules/es7.array.includes.js');
 require('../../node_modules/core-js/modules/es7.object.define-getter.js');
 require('../../node_modules/core-js/modules/es7.object.define-setter.js');
@@ -155,18 +157,21 @@ require('../../node_modules/core-js/modules/es7.object.values.js');
 require('../../node_modules/core-js/modules/es7.promise.finally.js');
 require('../../node_modules/core-js/modules/es7.string.pad-end.js');
 require('../../node_modules/core-js/modules/es7.string.pad-start.js');
+require('../../node_modules/core-js/modules/es7.string.trim-left.js');
+require('../../node_modules/core-js/modules/es7.string.trim-right.js');
 require('../../node_modules/core-js/modules/es7.symbol.async-iterator.js');
 require('../../node_modules/core-js/modules/web.dom.iterable.js');
 require('../../node_modules/core-js/modules/web.immediate.js');
 require('../../node_modules/core-js/modules/web.timers.js');
 require('../../node_modules/custom-event-polyfill/custom-event-polyfill.js');
-require('../../node_modules/d3-cloud/index.js');
+require('../../node_modules/d3-cloud/build/d3.layout.cloud.js');
 require('../../node_modules/d3/d3.js');
 require('../../node_modules/dragula/dragula.js');
 require('../../node_modules/encode-uri-query/index.js');
 require('../../node_modules/events/events.js');
 require('../../node_modules/handlebars/dist/handlebars.js');
 require('../../node_modules/hjson/lib/hjson.js');
+require('../../node_modules/inline-style/index.js');
 require('../../node_modules/json-stringify-pretty-compact/index.js');
 require('../../node_modules/leaflet-vega/dist/bundle.js');
 require('../../node_modules/less/lib/less-browser/index.js');
@@ -204,10 +209,12 @@ require('../../node_modules/redux/lib/redux.js');
 require('../../node_modules/regenerator-runtime/runtime.js');
 require('../../node_modules/reselect/lib/index.js');
 require('../../node_modules/resize-observer-polyfill/dist/ResizeObserver.js');
-require('../../node_modules/rison-node/build/rison.js');
+require('../../node_modules/rison-node/js/rison.js');
 require('../../node_modules/rxjs/index.js');
 require('../../node_modules/rxjs/operators/index.js');
+require('../../node_modules/semver/semver.js');
 require('../../node_modules/stream-browserify/index.js');
+require('../../node_modules/symbol-observable/lib/index.js');
 require('../../node_modules/timers-browserify/main.js');
 require('../../node_modules/topojson-client/dist/topojson-client.js');
 require('../../node_modules/trunc-html/index.js');
