@@ -16,30 +16,43 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import { DocTitleProvider } from 'ui/doc_title';
+import { docTitle } from 'ui/doc_title';
 
 import { applyResizeCheckerToEditors } from '../sense_editor_resize';
 import $ from 'jquery';
 import { initializeInput } from '../input';
 import { initializeOutput } from '../output';
 import init from '../app';
-import { SenseTopNavController } from './sense_top_nav_controller';
 import { getEndpointFromPosition } from '../autocomplete';
 import { DOC_LINK_VERSION } from 'ui/documentation_links';
 
+// welcome message
+import { showWelcomePanel } from '../helpers/welcome_show_panel';
+import storage from '../storage';
+
+import { getTopNavConfig } from '../helpers/get_top_nav';
+
 const module = require('ui/modules').get('app/sense');
 
-module.run(function (Private, $rootScope) {
+module.run(function ($rootScope) {
   module.setupResizeCheckerForRootEditors = ($el, ...editors) => {
     return applyResizeCheckerToEditors($rootScope, $el, ...editors);
   };
 });
 
-module.controller('SenseController', function SenseController(Private, $scope, $timeout, $location, kbnUiAceKeyboardModeService) {
-  const docTitle = Private(DocTitleProvider);
+function showWelcomeMessageIfNeeded($scope) {
+  if (storage.get('version_welcome_shown') !== '@@SENSE_REVISION') {
+    const hideWelcomePanel = showWelcomePanel();
+    $scope.$on('$destroy', () => {
+      hideWelcomePanel();
+    });
+  }
+}
+
+module.controller('SenseController', function SenseController($scope, $timeout, $location, kbnUiAceKeyboardModeService) {
   docTitle.change('Console');
 
-  $scope.topNavController = Private(SenseTopNavController);
+  showWelcomeMessageIfNeeded($scope);
 
   // Since we pass this callback via reactDirective into a react component, which has the function defined as required
   // in it's prop types, we should set this initially (before it's set in the $timeout below). Without this line
@@ -86,6 +99,19 @@ module.controller('SenseController', function SenseController(Private, $scope, $
       }
     });
   };
+
+  $scope.showHistory = false;
+  $scope.historyDirty = undefined;
+  $scope.toggleHistory = () => {
+    $scope.showHistory = !$scope.showHistory;
+  };
+
+  $scope.closeHistory = () => {
+    $scope.showHistory = false;
+  };
+
+  $scope.topNavMenu = getTopNavConfig($scope, $scope.toggleHistory);
+
   $scope.openDocumentation = () => {
     if (!$scope.documentation) {
       return;
@@ -95,7 +121,11 @@ module.controller('SenseController', function SenseController(Private, $scope, $
 
   $scope.sendSelected = () => {
     input.focus();
-    input.sendCurrentRequestToES();
+    input.sendCurrentRequestToES(() => {
+      // History watches this value and will re-render itself when it changes, so that
+      // the list of requests stays up-to-date as new requests are sent.
+      $scope.lastRequestTimestamp = new Date().getTime();
+    });
     return false;
   };
 
