@@ -17,7 +17,9 @@
  * under the License.
  */
 
+import src from '!!raw-loader!./worker.js';
+
 export const workerModule = {
   id: 'sense_editor/mode/worker',
-  src: require('!!raw-loader!./worker.js')
+  src
 };
