@@ -42,61 +42,68 @@ import {
 const basePath = chrome.getBasePath();
 
 const AddDataUi = ({ apmUiEnabled, isNewKibanaInstance, intl, mlEnabled }) => {
-
   const renderCards = () => {
-    const ampData = {
+    const apmData = {
       title: intl.formatMessage({
-        id: 'kbn.home.addData.apm.nameTitle', defaultMessage: 'APM'
+        id: 'kbn.home.addData.apm.nameTitle',
+        defaultMessage: 'APM',
       }),
       description: intl.formatMessage({
         id: 'kbn.home.addData.apm.nameDescription',
-        defaultMessage: 'APM automatically collects in-depth performance metrics and errors from inside your applications.'
+        defaultMessage:
+          'APM automatically collects in-depth performance metrics and errors from inside your applications.',
       }),
-      ariaDescribedby: 'aria-describedby.addAmpButtonLabel'
+      ariaDescribedby: 'aria-describedby.addAmpButtonLabel',
     };
     const loggingData = {
       title: intl.formatMessage({
-        id: 'kbn.home.addData.logging.nameTitle', defaultMessage: 'Logging'
+        id: 'kbn.home.addData.logging.nameTitle',
+        defaultMessage: 'Logging',
       }),
       description: intl.formatMessage({
         id: 'kbn.home.addData.logging.nameDescription',
-        defaultMessage: 'Ingest logs from popular data sources and easily visualize in preconfigured dashboards.'
+        defaultMessage:
+          'Ingest logs from popular data sources and easily visualize in preconfigured dashboards.',
       }),
-      ariaDescribedby: 'aria-describedby.addLogDataButtonLabel'
+      ariaDescribedby: 'aria-describedby.addLogDataButtonLabel',
     };
     const metricsData = {
       title: intl.formatMessage({
-        id: 'kbn.home.addData.metrics.nameTitle', defaultMessage: 'Metrics'
+        id: 'kbn.home.addData.metrics.nameTitle',
+        defaultMessage: 'Metrics',
       }),
       description: intl.formatMessage({
         id: 'kbn.home.addData.metrics.nameDescription',
-        defaultMessage: 'Collect metrics from the operating system and services running on your servers.'
+        defaultMessage:
+          'Collect metrics from the operating system and services running on your servers.',
       }),
-      ariaDescribedby: 'aria-describedby.addMetricsButtonLabel'
+      ariaDescribedby: 'aria-describedby.addMetricsButtonLabel',
     };
-    const securityData = {
+    const siemData = {
       title: intl.formatMessage({
-        id: 'kbn.home.addData.security.nameTitle', defaultMessage: 'Security analytics'
+        id: 'kbn.home.addData.siem.nameTitle',
+        defaultMessage: 'SIEM',
       }),
       description: intl.formatMessage({
-        id: 'kbn.home.addData.security.nameDescription',
-        defaultMessage: 'Centralize security events for interactive investigation in ready-to-go visualizations.'
+        id: 'kbn.home.addData.siem.nameDescription',
+        defaultMessage:
+          'Centralize security events for interactive investigation in ready-to-go visualizations.',
       }),
-      ariaDescribedby: 'aria-describedby.addSecurityButtonLabel'
+      ariaDescribedby: 'aria-describedby.addSiemButtonLabel',
     };
 
-    const getApmCard = () =>  (
+    const getApmCard = () => (
       <EuiFlexItem grow={false}>
         <EuiCard
           className="homAddData__card"
           icon={<EuiIcon className="homAddData__icon" type="apmApp" />}
-          title={ampData.title}
-          description={<span id={ampData.ariaDescribedby}>{ampData.description}</span>}
+          title={apmData.title}
+          description={<span id={apmData.ariaDescribedby}>{apmData.description}</span>}
           footer={
             <EuiButton
               className="homAddData__button"
               href="#/home/tutorial/apm"
-              aria-describedby={ampData.ariaDescribedby}
+              aria-describedby={apmData.ariaDescribedby}
             >
               <FormattedMessage
                 id="kbn.home.addData.apm.addApmButtonLabel"
@@ -109,14 +116,19 @@ const AddDataUi = ({ apmUiEnabled, isNewKibanaInstance, intl, mlEnabled }) => {
     );
 
     return (
-      <EuiFlexGroup className="homeAddData__flexGroup" wrap={apmUiEnabled} gutterSize="l" justifyContent="spaceAround" responsive={false}>
-
+      <EuiFlexGroup
+        className="homeAddData__flexGroup"
+        wrap={apmUiEnabled}
+        gutterSize="l"
+        justifyContent="spaceAround"
+        responsive={false}
+      >
         {apmUiEnabled !== false && getApmCard()}
 
         <EuiFlexItem grow={false}>
           <EuiCard
             className="homAddData__card"
-            icon={<EuiIcon  className="homAddData__icon" type="loggingApp" />}
+            icon={<EuiIcon className="homAddData__icon" type="loggingApp" />}
             title={loggingData.title}
             description={<span id={loggingData.ariaDescribedby}>{loggingData.description}</span>}
             footer={
@@ -158,17 +170,17 @@ const AddDataUi = ({ apmUiEnabled, isNewKibanaInstance, intl, mlEnabled }) => {
         <EuiFlexItem grow={false}>
           <EuiCard
             className="homAddData__card"
-            icon={<EuiIcon className="homAddData__icon" type="securityApp" />}
-            title={securityData.title}
-            description={<span id={securityData.ariaDescribedby}>{securityData.description}</span>}
+            icon={<EuiIcon className="homAddData__icon" type="securityAnalyticsApp" />}
+            title={siemData.title}
+            description={<span id={siemData.ariaDescribedby}>{siemData.description}</span>}
             footer={
               <EuiButton
                 className="homAddData__button"
-                href="#/home/tutorial_directory/security"
-                aria-describedby={securityData.ariaDescribedby}
+                href="#/home/tutorial_directory/siem"
+                aria-describedby={siemData.ariaDescribedby}
               >
                 <FormattedMessage
-                  id="kbn.home.addData.security.addSecurityEventsButtonLabel"
+                  id="kbn.home.addData.siem.addSiemEventsButtonLabel"
                   defaultMessage="Add security events"
                 />
               </EuiButton>
@@ -179,7 +191,9 @@ const AddDataUi = ({ apmUiEnabled, isNewKibanaInstance, intl, mlEnabled }) => {
     );
   };
 
-  const footerItemClasses = classNames('homAddData__footerItem', { 'homAddData__footerItem--highlight': isNewKibanaInstance });
+  const footerItemClasses = classNames('homAddData__footerItem', {
+    'homAddData__footerItem--highlight': isNewKibanaInstance,
+  });
 
   return (
     <EuiPanel paddingSize="l">
@@ -230,7 +244,7 @@ const AddDataUi = ({ apmUiEnabled, isNewKibanaInstance, intl, mlEnabled }) => {
             </EuiLink>
           </EuiText>
         </EuiFlexItem>
-        {mlEnabled !== false ?
+        {mlEnabled !== false ? (
           <EuiFlexItem className={footerItemClasses}>
             <EuiText size="s">
               <strong style={{ height: 38 }}>
@@ -250,8 +264,7 @@ const AddDataUi = ({ apmUiEnabled, isNewKibanaInstance, intl, mlEnabled }) => {
               </EuiLink>
             </EuiText>
           </EuiFlexItem>
-          : null
-        }
+        ) : null}
         <EuiFlexItem className={footerItemClasses}>
           <EuiText size="s">
             <strong style={{ height: 38 }}>
