@@ -21,13 +21,13 @@ import PropTypes from 'prop-types';
 import React, { Component } from 'react';
 import _ from 'lodash';
 import uuid from 'uuid';
-import AggRow from './agg_row';
-import AggSelect from './agg_select';
+import { AggRow } from './agg_row';
+import { AggSelect } from './agg_select';
 
-import createChangeHandler from '../lib/create_change_handler';
-import createSelectHandler from '../lib/create_select_handler';
-import createTextHandler from '../lib/create_text_handler';
-import Vars from './vars';
+import { createChangeHandler } from '../lib/create_change_handler';
+import { createSelectHandler } from '../lib/create_select_handler';
+import { createTextHandler } from '../lib/create_text_handler';
+import { CalculationVars } from './vars';
 import { FormattedMessage } from '@kbn/i18n/react';
 
 import {
@@ -40,13 +40,14 @@ import {
   EuiCode,
 } from '@elastic/eui';
 
-class CalculationAgg extends Component {
-
+export class CalculationAgg extends Component {
   componentWillMount() {
     if (!this.props.model.variables) {
-      this.props.onChange(_.assign({}, this.props.model, {
-        variables: [{ id: uuid.v1() }]
-      }));
+      this.props.onChange(
+        _.assign({}, this.props.model, {
+          variables: [{ id: uuid.v1() }],
+        })
+      );
     }
   }
 
@@ -90,12 +91,9 @@ class CalculationAgg extends Component {
 
           <EuiFlexItem>
             <EuiFormLabel htmlFor={htmlId('variables')}>
-              <FormattedMessage
-                id="tsvb.calculation.variablesLabel"
-                defaultMessage="Variables"
-              />
+              <FormattedMessage id="tsvb.calculation.variablesLabel" defaultMessage="Variables" />
             </EuiFormLabel>
-            <Vars
+            <CalculationVars
               id={htmlId('variables')}
               metrics={siblings}
               onChange={handleChange}
@@ -107,10 +105,12 @@ class CalculationAgg extends Component {
           <EuiFlexItem>
             <EuiFormRow
               id={htmlId('painless')}
-              label={(<FormattedMessage
-                id="tsvb.calculation.painlessScriptLabel"
-                defaultMessage="Painless Script"
-              />)}
+              label={
+                <FormattedMessage
+                  id="tsvb.calculation.painlessScriptLabel"
+                  defaultMessage="Painless Script"
+                />
+              }
               fullWidth
               helpText={
                 <div>
@@ -119,26 +119,21 @@ class CalculationAgg extends Component {
                     defaultMessage="Variables are keys on the {params} object, i.e. {paramsName}. To access the bucket
                     interval (in milliseconds) use {paramsInterval}."
                     values={{
-                      params: (<EuiCode>params</EuiCode>),
-                      paramsName: (<EuiCode>params.&lt;name&gt;</EuiCode>),
-                      paramsInterval: (<EuiCode>params._interval</EuiCode>)
+                      params: <EuiCode>params</EuiCode>,
+                      paramsName: <EuiCode>params.&lt;name&gt;</EuiCode>,
+                      paramsInterval: <EuiCode>params._interval</EuiCode>,
                     }}
                   />
                 </div>
               }
             >
-              <EuiTextArea
-                onChange={handleTextChange('script')}
-                value={model.script}
-                fullWidth
-              />
+              <EuiTextArea onChange={handleTextChange('script')} value={model.script} fullWidth />
             </EuiFormRow>
           </EuiFlexItem>
         </EuiFlexGroup>
       </AggRow>
     );
   }
-
 }
 
 CalculationAgg.propTypes = {
@@ -152,5 +147,3 @@ CalculationAgg.propTypes = {
   series: PropTypes.object,
   siblings: PropTypes.array,
 };
-
-export default CalculationAgg;
