@@ -19,14 +19,13 @@
 
 import PropTypes from 'prop-types';
 import React, { Component } from 'react';
-import SeriesEditor from '../series_editor';
+import { SeriesEditor } from '../series_editor';
 import { IndexPattern } from '../index_pattern';
 import 'brace/mode/less';
-import createSelectHandler from '../lib/create_select_handler';
-import createTextHandler from '../lib/create_text_handler';
-import ColorPicker from '../color_picker';
-import YesNo from '../yes_no';
-import MarkdownEditor from '../markdown_editor';
+import { createSelectHandler } from '../lib/create_select_handler';
+import { ColorPicker } from '../color_picker';
+import { YesNo } from '../yes_no';
+import { MarkdownEditor } from '../markdown_editor';
 import less from 'less/lib/less-browser';
 import {
   htmlIdGenerator,
@@ -39,16 +38,19 @@ import {
   EuiFormRow,
   EuiFormLabel,
   EuiSpacer,
-  EuiFieldText,
   EuiTitle,
   EuiHorizontalRule,
   EuiCodeEditor,
 } from '@elastic/eui';
 const lessC = less(window, { env: 'production' });
 import { injectI18n, FormattedMessage } from '@kbn/i18n/react';
+import { Storage } from 'ui/storage';
+import { data } from 'plugins/data/setup';
+import { getDefaultQueryLanguage } from '../lib/get_default_query_language';
+const { QueryBarInput } = data.query.ui;
+const localStorage = new Storage(window.localStorage);
 
 class MarkdownPanelConfigUi extends Component {
-
   constructor(props) {
     super(props);
     this.state = { selectedTab: 'markdown' };
@@ -74,35 +76,43 @@ class MarkdownPanelConfigUi extends Component {
   }
 
   render() {
-    const defaults = { filter: '' };
+    const defaults = { filter: { query: '', language: getDefaultQueryLanguage() } };
     const model = { ...defaults, ...this.props.model };
     const { selectedTab } = this.state;
     const handleSelectChange = createSelectHandler(this.props.onChange);
-    const handleTextChange = createTextHandler(this.props.onChange);
     const { intl } = this.props;
 
     const htmlId = htmlIdGenerator();
 
     const alignOptions = [
       {
-        label: intl.formatMessage({ id: 'tsvb.markdown.alignOptions.topLabel', defaultMessage: 'Top' }),
-        value: 'top'
+        label: intl.formatMessage({
+          id: 'tsvb.markdown.alignOptions.topLabel',
+          defaultMessage: 'Top',
+        }),
+        value: 'top',
       },
       {
-        label: intl.formatMessage({ id: 'tsvb.markdown.alignOptions.middleLabel', defaultMessage: 'Middle' }),
-        value: 'middle'
+        label: intl.formatMessage({
+          id: 'tsvb.markdown.alignOptions.middleLabel',
+          defaultMessage: 'Middle',
+        }),
+        value: 'middle',
       },
       {
-        label: intl.formatMessage({ id: 'tsvb.markdown.alignOptions.bottomLabel', defaultMessage: 'Bottom' }),
-        value: 'bottom'
-      }
+        label: intl.formatMessage({
+          id: 'tsvb.markdown.alignOptions.bottomLabel',
+          defaultMessage: 'Bottom',
+        }),
+        value: 'bottom',
+      },
     ];
     const selectedAlignOption = alignOptions.find(option => {
       return model.markdown_vertical_align === option.value;
     });
     let view;
     if (selectedTab === 'markdown') {
-      view = (<MarkdownEditor {...this.props}/>);
+      view = <MarkdownEditor {...this.props} />;
     } else if (selectedTab === 'data') {
       view = (
         <SeriesEditor
@@ -120,10 +130,7 @@ class MarkdownPanelConfigUi extends Component {
           <EuiPanel>
             <EuiTitle size="s">
               <span>
-                <FormattedMessage
-                  id="tsvb.markdown.optionsTab.dataLabel"
-                  defaultMessage="Data"
-                />
+                <FormattedMessage id="tsvb.markdown.optionsTab.dataLabel" defaultMessage="Data" />
               </span>
             </EuiTitle>
             <EuiSpacer size="m" />
@@ -140,16 +147,25 @@ class MarkdownPanelConfigUi extends Component {
               <EuiFlexItem>
                 <EuiFormRow
                   id={htmlId('panelFilter')}
-                  label={(<FormattedMessage
-                    id="tsvb.markdown.optionsTab.panelFilterLabel"
-                    defaultMessage="Panel filter"
-                  />)}
+                  label={
+                    <FormattedMessage
+                      id="tsvb.markdown.optionsTab.panelFilterLabel"
+                      defaultMessage="Panel filter"
+                    />
+                  }
                   fullWidth
                 >
-                  <EuiFieldText
-                    onChange={handleTextChange('filter')}
-                    value={model.filter}
-                    fullWidth
+                  <QueryBarInput
+                    query={{
+                      language: model.filter.language
+                        ? model.filter.language
+                        : getDefaultQueryLanguage(),
+                      query: model.filter.query || '',
+                    }}
+                    onChange={filter => this.props.onChange({ filter })}
+                    appName={'VisEditor'}
+                    indexPatterns={[model.index_pattern || model.default_index_pattern]}
+                    store={localStorage}
                   />
                 </EuiFormRow>
               </EuiFlexItem>
@@ -175,10 +191,7 @@ class MarkdownPanelConfigUi extends Component {
           <EuiPanel>
             <EuiTitle size="s">
               <span>
-                <FormattedMessage
-                  id="tsvb.markdown.optionsTab.styleLabel"
-                  defaultMessage="Style"
-                />
+                <FormattedMessage id="tsvb.markdown.optionsTab.styleLabel" defaultMessage="Style" />
               </span>
             </EuiTitle>
             <EuiSpacer size="m" />
@@ -290,10 +303,7 @@ class MarkdownPanelConfigUi extends Component {
             isSelected={selectedTab === 'data'}
             onClick={() => this.switchTab('data')}
           >
-            <FormattedMessage
-              id="tsvb.markdown.dataTab.dataButtonLabel"
-              defaultMessage="Data"
-            />
+            <FormattedMessage id="tsvb.markdown.dataTab.dataButtonLabel" defaultMessage="Data" />
           </EuiTab>
           <EuiTab
             isSelected={selectedTab === 'options'}
@@ -320,5 +330,4 @@ MarkdownPanelConfigUi.propTypes = {
   visData$: PropTypes.object,
 };
 
-const MarkdownPanelConfig = injectI18n(MarkdownPanelConfigUi);
-export default MarkdownPanelConfig;
+export const MarkdownPanelConfig = injectI18n(MarkdownPanelConfigUi);
