@@ -17,30 +17,32 @@
  * under the License.
  */
 
-import createTextHandler from '../lib/create_text_handler';
-import createSelectHandler from '../lib/create_select_handler';
+import { createSelectHandler } from '../lib/create_select_handler';
 import { GroupBySelect } from './group_by_select';
 import PropTypes from 'prop-types';
 import React from 'react';
-import { htmlIdGenerator, EuiFlexGroup, EuiFlexItem, EuiFormRow, EuiFieldText } from '@elastic/eui';
+import { data } from 'plugins/data/setup';
+const { QueryBarInput } = data.query.ui;
+import { Storage } from 'ui/storage';
+import { htmlIdGenerator, EuiFlexGroup, EuiFlexItem, EuiFormRow } from '@elastic/eui';
 import { FormattedMessage } from '@kbn/i18n/react';
+import { getDefaultQueryLanguage } from '../lib/get_default_query_language';
+const localStorage = new Storage(window.localStorage);
 
 export const SplitByFilter = props => {
-  const { onChange, uiRestrictions } = props;
-  const defaults = { filter: '' };
+  const { onChange, uiRestrictions, indexPattern } = props;
+  const defaults = { filter: { language: getDefaultQueryLanguage(), query: '' } };
   const model = { ...defaults, ...props.model };
   const htmlId = htmlIdGenerator();
-  const handleTextChange = createTextHandler(onChange);
   const handleSelectChange = createSelectHandler(onChange);
   return (
     <EuiFlexGroup alignItems="center">
       <EuiFlexItem>
         <EuiFormRow
           id={htmlId('group')}
-          label={(<FormattedMessage
-            id="tsvb.splits.filter.groupByLabel"
-            defaultMessage="Group by"
-          />)}
+          label={
+            <FormattedMessage id="tsvb.splits.filter.groupByLabel" defaultMessage="Group by" />
+          }
         >
           <GroupBySelect
             value={model.split_mode}
@@ -52,14 +54,22 @@ export const SplitByFilter = props => {
       <EuiFlexItem>
         <EuiFormRow
           id={htmlId('query')}
-          label={(<FormattedMessage
-            id="tsvb.splits.filter.queryStringLabel"
-            defaultMessage="Query string"
-          />)}
+          label={
+            <FormattedMessage
+              id="tsvb.splits.filter.queryStringLabel"
+              defaultMessage="Query string"
+            />
+          }
         >
-          <EuiFieldText
-            value={model.filter}
-            onChange={handleTextChange('filter')}
+          <QueryBarInput
+            query={{
+              language: model.filter.language || getDefaultQueryLanguage(),
+              query: model.filter.query || '',
+            }}
+            onChange={filter => onChange({ filter })}
+            appName={'VisEditor'}
+            indexPatterns={[indexPattern]}
+            store={localStorage}
           />
         </EuiFormRow>
       </EuiFlexItem>
@@ -71,4 +81,5 @@ SplitByFilter.propTypes = {
   model: PropTypes.object,
   onChange: PropTypes.func,
   uiRestrictions: PropTypes.object,
+  indexPatterns: PropTypes.string,
 };
