@@ -21,11 +21,11 @@ import _, { isArray, last, get } from 'lodash';
 import React, { Component } from 'react';
 import PropTypes from 'prop-types';
 import { fieldFormats } from 'ui/registry/field_formats';
-import tickFormatter from '../../lib/tick_formatter';
-import calculateLabel from '../../../../common/calculate_label';
+import { tickFormatter } from '../../lib/tick_formatter';
+import { calculateLabel } from '../../../../common/calculate_label';
 import { isSortable } from './is_sortable';
 import { EuiToolTip, EuiIcon } from '@elastic/eui';
-import replaceVars from '../../lib/replace_vars';
+import { replaceVars } from '../../lib/replace_vars';
 import { FormattedMessage } from '@kbn/i18n/react';
 
 import { METRIC_TYPES } from '../../../../common/metric_types';
@@ -35,7 +35,7 @@ const DateFormat = fieldFormats.getType('date');
 function getColor(rules, colorKey, value) {
   let color;
   if (rules) {
-    rules.forEach((rule) => {
+    rules.forEach(rule => {
       if (rule.operator && rule.value != null) {
         if (_[rule.operator](value, rule.value)) {
           color = rule[colorKey];
@@ -46,8 +46,7 @@ function getColor(rules, colorKey, value) {
   return color;
 }
 
-class TableVis extends Component {
-
+export class TableVis extends Component {
   constructor(props) {
     super(props);
     this.dateFormatter = new DateFormat({}, this.props.getConfig);
@@ -62,30 +61,41 @@ class TableVis extends Component {
     let rowDisplay = model.pivot_type === 'date' ? this.dateFormatter.convert(row.key) : row.key;
     if (model.drilldown_url) {
       const url = replaceVars(model.drilldown_url, {}, { key: row.key });
-      rowDisplay = (<a href={url}>{rowDisplay}</a>);
+      rowDisplay = <a href={url}>{rowDisplay}</a>;
     }
-    const columns = row.series.filter(item => item).map(item => {
-      const column = this.visibleSeries.find(c => c.id === item.id);
-      if (!column) return null;
-      const formatter = tickFormatter(column.formatter, column.value_template, this.props.getConfig);
-      const value = formatter(item.last);
-      let trend;
-      if (column.trend_arrows) {
-        const trendIcon = item.slope > 0 ? 'sortUp' : 'sortDown';
-        trend = (
-          <span>
-            &nbsp; <EuiIcon type={trendIcon} color="subdued"/>
-          </span>
+    const columns = row.series
+      .filter(item => item)
+      .map(item => {
+        const column = this.visibleSeries.find(c => c.id === item.id);
+        if (!column) return null;
+        const formatter = tickFormatter(
+          column.formatter,
+          column.value_template,
+          this.props.getConfig
         );
-      }
-      const style = { color: getColor(column.color_rules, 'text', item.last) };
-      return (
-        <td key={`${row.key}-${item.id}`} data-test-subj="tvbTableVis__value" className="eui-textRight" style={style}>
-          <span>{value}</span>
-          {trend}
-        </td>
-      );
-    });
+        const value = formatter(item.last);
+        let trend;
+        if (column.trend_arrows) {
+          const trendIcon = item.slope > 0 ? 'sortUp' : 'sortDown';
+          trend = (
+            <span>
+              &nbsp; <EuiIcon type={trendIcon} color="subdued" />
+            </span>
+          );
+        }
+        const style = { color: getColor(column.color_rules, 'text', item.last) };
+        return (
+          <td
+            key={`${row.key}-${item.id}`}
+            data-test-subj="tvbTableVis__value"
+            className="eui-textRight"
+            style={style}
+          >
+            <span>{value}</span>
+            {trend}
+          </td>
+        );
+      });
     return (
       <tr key={row.key}>
         <td>{rowDisplay}</td>
@@ -137,20 +147,22 @@ class TableVis extends Component {
         } else {
           sortIcon = 'empty';
         }
-        sortComponent = (
-          <EuiIcon type={sortIcon}/>
-        );
+        sortComponent = <EuiIcon type={sortIcon} />;
       }
       let headerContent = (
-        <span>{label} {sortComponent}</span>
+        <span>
+          {label} {sortComponent}
+        </span>
       );
       if (!isSortable(metric)) {
         headerContent = (
           <EuiToolTip
-            content={(<FormattedMessage
-              id="tsvb.table.columnNotSortableTooltip"
-              defaultMessage="This column is not sortable"
-            />)}
+            content={
+              <FormattedMessage
+                id="tsvb.table.columnNotSortableTooltip"
+                defaultMessage="This column is not sortable"
+              />
+            }
           >
             {headerContent}
           </EuiToolTip>
@@ -158,11 +170,7 @@ class TableVis extends Component {
       }
 
       return (
-        <th
-          onClick={handleClick}
-          key={item.id}
-          scope="col"
-        >
+        <th onClick={handleClick} key={item.id} scope="col">
           {headerContent}
         </th>
       );
@@ -174,9 +182,7 @@ class TableVis extends Component {
     } else {
       sortIcon = 'empty';
     }
-    const sortComponent = (
-      <EuiIcon type={sortIcon}/>
-    );
+    const sortComponent = <EuiIcon type={sortIcon} />;
     const handleSortClick = () => {
       let order;
       if (sort.column === '_default_') {
@@ -188,7 +194,9 @@ class TableVis extends Component {
     };
     return (
       <tr>
-        <th className="eui-textLeft" scope="col" onClick={handleSortClick}>{label} {sortComponent}</th>
+        <th className="eui-textLeft" scope="col" onClick={handleSortClick}>
+          {label} {sortComponent}
+        </th>
         {columns}
       </tr>
     );
@@ -202,39 +210,32 @@ class TableVis extends Component {
     if (isArray(visData.series) && visData.series.length) {
       rows = visData.series.map(this.renderRow);
     } else {
-      const message = model.pivot_id ?
-        (<FormattedMessage
+      const message = model.pivot_id ? (
+        <FormattedMessage
           id="tsvb.table.noResultsAvailableMessage"
           defaultMessage="No results available."
-        />)
-        : (<FormattedMessage
+        />
+      ) : (
+        <FormattedMessage
           id="tsvb.table.noResultsAvailableWithDescriptionMessage"
           defaultMessage="No results available. You must choose a group by field for this visualization."
-        />);
+        />
+      );
       rows = (
         <tr>
-          <td
-            colSpan={this.visibleSeries.length + 1}
-          >
-            {message}
-          </td>
+          <td colSpan={this.visibleSeries.length + 1}>{message}</td>
         </tr>
       );
     }
     return (
       <div className="tvbVis" data-test-subj="tableView">
         <table className="table">
-          <thead>
-            {header}
-          </thead>
-          <tbody>
-            {rows}
-          </tbody>
+          <thead>{header}</thead>
+          <tbody>{rows}</tbody>
         </table>
       </div>
     );
   }
-
 }
 
 TableVis.defaultProps = {
@@ -251,5 +252,3 @@ TableVis.propTypes = {
   pageNumber: PropTypes.number,
   getConfig: PropTypes.func,
 };
-
-export default TableVis;
