@@ -22,7 +22,7 @@ import _ from 'lodash';
 import { i18n } from '@kbn/i18n';
 
 import { capabilities } from 'ui/capabilities';
-import { DocTitleProvider } from 'ui/doc_title';
+import { docTitle } from 'ui/doc_title';
 import { SavedObjectRegistryProvider } from 'ui/saved_objects/saved_object_registry';
 import { notify, fatalError, toastNotifications } from 'ui/notify';
 import { timezoneProvider } from 'ui/vis/lib/timezone';
@@ -43,12 +43,17 @@ import 'ui/listen';
 import 'ui/kbn_top_nav';
 import 'ui/saved_objects/ui/saved_object_save_as_checkbox';
 
+import rootTemplate from 'plugins/timelion/index.html';
+
 require('plugins/timelion/directives/cells/cells');
 require('plugins/timelion/directives/fixed_element');
 require('plugins/timelion/directives/fullscreen/fullscreen');
 require('plugins/timelion/directives/timelion_expression_input');
 require('plugins/timelion/directives/timelion_help/timelion_help');
 require('plugins/timelion/directives/timelion_interval/timelion_interval');
+require('plugins/timelion/directives/timelion_save_sheet');
+require('plugins/timelion/directives/timelion_load_sheet');
+require('plugins/timelion/directives/timelion_options_sheet');
 
 document.title = 'Timelion - Kibana';
 
@@ -67,7 +72,7 @@ require('ui/routes').enable();
 
 require('ui/routes')
   .when('/:id?', {
-    template: require('plugins/timelion/index.html'),
+    template: rootTemplate,
     reloadOnSearch: false,
     k7Breadcrumbs: ($injector, $route) => $injector.invoke(
       $route.current.params.id
@@ -119,9 +124,7 @@ app.controller('timelion', function (
   AppState,
   config,
   confirmModal,
-  courier,
   kbnUrl,
-  Notifier,
   Private
 ) {
 
@@ -133,13 +136,8 @@ app.controller('timelion', function (
   timefilter.enableAutoRefreshSelector();
   timefilter.enableTimeRangeSelector();
 
-  const notify = new Notifier({
-    location
-  });
-
   const savedVisualizations = Private(SavedObjectRegistryProvider).byLoaderPropertiesName.visualizations;
   const timezone = Private(timezoneProvider)();
-  const docTitle = Private(DocTitleProvider);
 
   const defaultExpression = '.es(*)';
   const savedSheet = $route.current.locals.savedSheet;
@@ -198,7 +196,11 @@ app.controller('timelion', function (
       description: i18n.translate('timelion.topNavMenu.saveSheetButtonAriaLabel', {
         defaultMessage: 'Save Sheet',
       }),
-      template: require('plugins/timelion/partials/save_sheet.html'),
+      run: () => {
+        const curState = $scope.menus.showSave;
+        $scope.closeMenus();
+        $scope.menus.showSave = !curState;
+      },
       testId: 'timelionSaveButton',
     };
 
@@ -257,7 +259,11 @@ app.controller('timelion', function (
       description: i18n.translate('timelion.topNavMenu.openSheetButtonAriaLabel', {
         defaultMessage: 'Open Sheet',
       }),
-      template: require('plugins/timelion/partials/load_sheet.html'),
+      run: () => {
+        const curState = $scope.menus.showLoad;
+        $scope.closeMenus();
+        $scope.menus.showLoad = !curState;
+      },
       testId: 'timelionOpenButton',
     };
 
@@ -269,7 +275,11 @@ app.controller('timelion', function (
       description: i18n.translate('timelion.topNavMenu.optionsButtonAriaLabel', {
         defaultMessage: 'Options',
       }),
-      template: require('plugins/timelion/partials/sheet_options.html'),
+      run: () => {
+        const curState = $scope.menus.showOptions;
+        $scope.closeMenus();
+        $scope.menus.showOptions = !curState;
+      },
       testId: 'timelionOptionsButton',
     };
 
@@ -281,7 +291,11 @@ app.controller('timelion', function (
       description: i18n.translate('timelion.topNavMenu.helpButtonAriaLabel', {
         defaultMessage: 'Help',
       }),
-      template: '<timelion-help></timelion-help>',
+      run: () => {
+        const curState = $scope.menus.showHelp;
+        $scope.closeMenus();
+        $scope.menus.showHelp = !curState;
+      },
       testId: 'timelionDocsButton',
     };
 
@@ -310,6 +324,19 @@ app.controller('timelion', function (
         $scope.kbnTopNav.close('help');
       }
     };
+
+    $scope.menus = {
+      showHelp: false,
+      showSave: false,
+      showLoad: false,
+      showOptions: false,
+    };
+
+    $scope.closeMenus = () => {
+      _.forOwn($scope.menus, function (value, key) {
+        $scope.menus[key] = false;
+      });
+    };
   };
 
   let refresher;
@@ -381,8 +408,11 @@ app.controller('timelion', function (
 
         const err = new Error(resp.message);
         err.stack = resp.stack;
-        notify.error(err);
-
+        toastNotifications.addError(err, {
+          title: i18n.translate('timelion.searchErrorTitle', {
+            defaultMessage: 'Timelion request error',
+          }),
+        });
       });
   };
 
