@@ -20,13 +20,10 @@ var _new_platform = require("ui/new_platform");
  * specific language governing permissions and limitations
  * under the License.
  */
-(0, _new_platform.onStart)(function (_ref) {
-  var core = _ref.core;
-  var timelionUiEnabled = core.injectedMetadata.getInjectedVar('timelionUiEnabled');
+var timelionUiEnabled = _new_platform.npStart.core.injectedMetadata.getInjectedVar('timelionUiEnabled');
 
-  if (timelionUiEnabled === false) {
-    core.chrome.navLinks.update('timelion', {
-      hidden: true
-    });
-  }
-});
\ No newline at end of file
+if (timelionUiEnabled === false) {
+  _new_platform.npStart.core.chrome.navLinks.update('timelion', {
+    hidden: true
+  });
+}
\ No newline at end of file
