@@ -22,6 +22,7 @@ import ReactDOM from 'react-dom';
 import $ from 'jquery';
 
 import { uiModules } from '../../modules';
+import template from './kbn_chrome.html';
 
 import {
   notify,
@@ -30,6 +31,8 @@ import {
 } from '../../notify';
 
 import { I18nContext } from '../../i18n';
+import { npStart } from '../../new_platform';
+import { chromeHeaderNavControlsRegistry, NavControlSide } from '../../registry/chrome_header_nav_controls';
 
 export function kbnChromeProvider(chrome, internals) {
 
@@ -38,7 +41,7 @@ export function kbnChromeProvider(chrome, internals) {
     .directive('kbnChrome', () => {
       return {
         template() {
-          const $content = $(require('./kbn_chrome.html'));
+          const $content = $(template);
           const $app = $content.find('.application');
 
           if (internals.rootController) {
@@ -54,7 +57,7 @@ export function kbnChromeProvider(chrome, internals) {
         },
 
         controllerAs: 'chrome',
-        controller($scope, $location) {
+        controller($scope, $location, Private) {
           // Notifications
           $scope.notifList = notify._notifs;
 
@@ -62,6 +65,19 @@ export function kbnChromeProvider(chrome, internals) {
             return $location.path().split('/')[1];
           };
 
+          // Continue to support legacy nav controls not registered with the NP.
+          const navControls = Private(chromeHeaderNavControlsRegistry);
+          (navControls.bySide[NavControlSide.Left] || [])
+            .forEach(navControl => npStart.core.chrome.navControls.registerLeft({
+              order: navControl.order,
+              mount: navControl.render,
+            }));
+          (navControls.bySide[NavControlSide.Right] || [])
+            .forEach(navControl => npStart.core.chrome.navControls.registerRight({
+              order: navControl.order,
+              mount: navControl.render,
+            }));
+
           // Non-scope based code (e.g., React)
 
           // Banners
