@@ -1,4 +1,4 @@
-'use strict';
+"use strict";
 
 /*
  * Licensed to Elasticsearch B.V. under one or more contributor
@@ -18,6 +18,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 var moment = module.exports = require('../node_modules/moment-timezone/moment-timezone');
+
 moment.tz.load(require('../node_modules/moment-timezone/data/packed/latest.json'));
\ No newline at end of file
